@@ -7,12 +7,8 @@ models.py - Model (and hence database) definitions. This is the core of the
             helpdesk structure.
 """
 
-try:
-    from django.contrib.auth import get_user_model
-    User = get_user_model()
-except ImportError:
-    from django.contrib.auth.models import User
 from django.db import models
+from django.contrib.auth import get_user_model
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _, ugettext
 
@@ -187,6 +183,8 @@ class Queue(models.Model):
 
     class Meta:
         ordering = ('title',)
+        verbose_name = _('Queue')
+        verbose_name_plural = _('Queues')
 
     def _from_address(self):
         """
@@ -244,7 +242,7 @@ class Ticket(models.Model):
         (REOPENED_STATUS, _('Reopened')),
         (RESOLVED_STATUS, _('Resolved')),
         (CLOSED_STATUS, _('Closed')),
-        (DUPLICATE_STATUS, _('Duplicate')),        
+        (DUPLICATE_STATUS, _('Duplicate')),
     )
 
     PRIORITY_CHOICES = (
@@ -286,7 +284,7 @@ class Ticket(models.Model):
         )
 
     assigned_to = models.ForeignKey(
-        User,
+        settings.AUTH_USER_MODEL,
         related_name='assigned_to',
         blank=True,
         null=True,
@@ -353,7 +351,7 @@ class Ticket(models.Model):
             if self.assigned_to.get_full_name():
                 return self.assigned_to.get_full_name()
             else:
-                return self.assigned_to.username
+                return self.assigned_to.get_username()
     get_assigned_to = property(_get_assigned_to)
 
     def _get_ticket(self):
@@ -374,13 +372,17 @@ class Ticket(models.Model):
         return u"%shelpdesk/priorities/priority%s.png" % (settings.MEDIA_URL, self.priority)
     get_priority_img = property(_get_priority_img)
 
-    def _get_priority_span(self):
+    def _get_priority_css_class(self):
         """
-        A HTML <span> providing a CSS_styled representation of the priority.
+        Return the boostrap class corresponding to the priority.
         """
-        from django.utils.safestring import mark_safe
-        return mark_safe(u"<span class='priority%s'>%s</span>" % (self.priority, self.priority))
-    get_priority_span = property(_get_priority_span)
+        if self.priority == 2:
+            return "warning"
+        elif self.priority == 1:
+            return "danger"
+        else:
+            return ""
+    get_priority_css_class = property(_get_priority_css_class)
 
     def _get_status(self):
         """
@@ -443,6 +445,8 @@ class Ticket(models.Model):
     class Meta:
         get_latest_by = "created"
         ordering = ('id',)
+        verbose_name = _('Ticket')
+        verbose_name_plural = _('Tickets')
 
     def __unicode__(self):
         return u'%s %s' % (self.id, self.title)
@@ -491,8 +495,8 @@ class FollowUp(models.Model):
         )
 
     date = models.DateTimeField(
-        _('Date'), 
-        default = timezone.now()
+        _('Date'),
+        default = timezone.now
         )
 
     title = models.CharField(
@@ -517,7 +521,7 @@ class FollowUp(models.Model):
         )
 
     user = models.ForeignKey(
-        User,
+        settings.AUTH_USER_MODEL,
         blank=True,
         null=True,
         verbose_name=_('User'),
@@ -535,6 +539,8 @@ class FollowUp(models.Model):
 
     class Meta:
         ordering = ['date']
+        verbose_name = _('Follow-up')
+        verbose_name_plural = _('Follow-ups')
 
     def __unicode__(self):
         return u'%s' % self.title
@@ -590,6 +596,10 @@ class TicketChange(models.Model):
                 }
         return str
 
+    class Meta:
+        verbose_name = _('Ticket change')
+        verbose_name_plural = _('Ticket changes')
+
 
 def attachment_path(instance, filename):
     """
@@ -621,11 +631,12 @@ class Attachment(models.Model):
     file = models.FileField(
         _('File'),
         upload_to=attachment_path,
+        max_length=1000,
         )
 
     filename = models.CharField(
         _('Filename'),
-        max_length=100,
+        max_length=1000,
         )
 
     mime_type = models.CharField(
@@ -652,6 +663,8 @@ class Attachment(models.Model):
 
     class Meta:
         ordering = ['filename',]
+        verbose_name = _('Attachment')
+        verbose_name_plural = _('Attachments')
 
 
 class PreSetReply(models.Model):
@@ -690,6 +703,8 @@ class PreSetReply(models.Model):
 
     class Meta:
         ordering = ['name',]
+        verbose_name = _('Pre-set reply')
+        verbose_name_plural = _('Pre-set replies')
 
     def __unicode__(self):
         return u'%s' % self.name
@@ -728,6 +743,10 @@ class EscalationExclusion(models.Model):
     def __unicode__(self):
         return u'%s' % self.name
 
+    class Meta:
+        verbose_name = _('Escalation exclusion')
+        verbose_name_plural = _('Escalation exclusions')
+
 
 class EmailTemplate(models.Model):
     """
@@ -771,7 +790,7 @@ class EmailTemplate(models.Model):
         help_text=_('The same context is available here as in plain_text, '
             'above.'),
         )
-    
+
     locale = models.CharField(
         _('Locale'),
         max_length=10,
@@ -785,6 +804,8 @@ class EmailTemplate(models.Model):
 
     class Meta:
         ordering = ['template_name', 'locale']
+        verbose_name = _('e-mail template')
+        verbose_name_plural = _('e-mail templates')
 
 
 class KBCategory(models.Model):
@@ -811,6 +832,8 @@ class KBCategory(models.Model):
 
     class Meta:
         ordering = ['title',]
+        verbose_name = _('Knowledge base category')
+        verbose_name_plural = _('Knowledge base categories')
 
     def get_absolute_url(self):
         return ('helpdesk_kb_category', (), {'slug': self.slug})
@@ -876,6 +899,8 @@ class KBItem(models.Model):
 
     class Meta:
         ordering = ['title',]
+        verbose_name = _('Knowledge base item')
+        verbose_name_plural = _('Knowledge base items')
 
     def get_absolute_url(self):
         return ('helpdesk_kb_item', (self.id,))
@@ -885,7 +910,7 @@ class KBItem(models.Model):
 class SavedSearch(models.Model):
     """
     Allow a user to save a ticket search, eg their filtering and sorting
-    options, and optionally share it with other users. This lets people 
+    options, and optionally share it with other users. This lets people
     easily create a set of commonly-used filters, such as:
         * My tickets waiting on me
         * My tickets waiting on submitter
@@ -894,7 +919,7 @@ class SavedSearch(models.Model):
          etc...
     """
     user = models.ForeignKey(
-        User,
+        settings.AUTH_USER_MODEL,
         verbose_name=_('User'),
         )
 
@@ -922,16 +947,21 @@ class SavedSearch(models.Model):
         else:
             return u'%s' % self.title
 
+    class Meta:
+        verbose_name = _('Saved search')
+        verbose_name_plural = _('Saved searches')
+
+
 class UserSettings(models.Model):
     """
     A bunch of user-specific settings that we want to be able to define, such
-    as notification preferences and other things that should probably be 
+    as notification preferences and other things that should probably be
     configurable.
 
     We should always refer to user.usersettings.settings['setting_name'].
     """
 
-    user = models.OneToOneField(User)
+    user = models.OneToOneField(settings.AUTH_USER_MODEL)
 
     settings_pickled = models.TextField(
         _('Settings Dictionary'),
@@ -961,13 +991,13 @@ class UserSettings(models.Model):
         return u'Preferences for %s' % self.user
 
     class Meta:
-        verbose_name = 'User Settings'
-        verbose_name_plural = 'User Settings'
+        verbose_name = _('User Setting')
+        verbose_name_plural = _('User Settings')
 
 
 def create_usersettings(sender, created_models=[], instance=None, created=False, **kwargs):
     """
-    Helper function to create UserSettings instances as 
+    Helper function to create UserSettings instances as
     required, eg when we first create the UserSettings database
     table via 'syncdb' or when we save a new user.
 
@@ -975,14 +1005,15 @@ def create_usersettings(sender, created_models=[], instance=None, created=False,
     'DoesNotExist: UserSettings matching query does not exist.' errors.
     """
     from helpdesk.settings import DEFAULT_USER_SETTINGS
-    if sender == User and created:
+    if sender == settings.AUTH_USER_MODEL and created:
         # This is a new user, so lets create their settings entry.
         s, created = UserSettings.objects.get_or_create(user=instance, defaults={'settings': DEFAULT_USER_SETTINGS})
         s.save()
     elif UserSettings in created_models:
+        User = get_user_model()
         # We just created the UserSettings model, lets create a UserSettings
         # entry for each existing user. This will only happen once (at install
-        # time, or at upgrade) when the UserSettings model doesn't already 
+        # time, or at upgrade) when the UserSettings model doesn't already
         # exist.
         for u in User.objects.all():
             try:
@@ -992,12 +1023,16 @@ def create_usersettings(sender, created_models=[], instance=None, created=False,
                 s.save()
 
 models.signals.post_syncdb.connect(create_usersettings)
-models.signals.post_save.connect(create_usersettings, sender=User)
+try:
+    models.signals.post_save.connect(create_usersettings, sender=settings.AUTH_USER_MODEL)
+except:
+    signal_user = get_user_model()
+    models.signals.post_save.connect(create_usersettings, sender=signal_user)
 
 class IgnoreEmail(models.Model):
     """
-    This model lets us easily ignore e-mails from certain senders when 
-    processing IMAP and POP3 mailboxes, eg mails from postmaster or from 
+    This model lets us easily ignore e-mails from certain senders when
+    processing IMAP and POP3 mailboxes, eg mails from postmaster or from
     known trouble-makers.
     """
     queues = models.ManyToManyField(
@@ -1068,13 +1103,18 @@ class IgnoreEmail(models.Model):
         else:
             return False
 
+    class Meta:
+        verbose_name = _('Ignored e-mail address')
+        verbose_name_plural = _('Ignored e-mail addresses')
+
+
 class TicketCC(models.Model):
     """
-    Often, there are people who wish to follow a ticket who aren't the 
+    Often, there are people who wish to follow a ticket who aren't the
     person who originally submitted it. This model provides a way for those
     people to follow a ticket.
 
-    In this circumstance, a 'person' could be either an e-mail address or 
+    In this circumstance, a 'person' could be either an e-mail address or
     an existing system user.
     """
 
@@ -1084,7 +1124,7 @@ class TicketCC(models.Model):
         )
 
     user = models.ForeignKey(
-        User,
+        settings.AUTH_USER_MODEL,
         blank=True,
         null=True,
         help_text=_('User who wishes to receive updates for this ticket.'),
@@ -1101,12 +1141,14 @@ class TicketCC(models.Model):
     can_view = models.BooleanField(
         _('Can View Ticket?'),
         blank=True,
+        default=False,
         help_text=_('Can this CC login to view the ticket details?'),
         )
 
     can_update = models.BooleanField(
         _('Can Update Ticket?'),
         blank=True,
+        default=False,
         help_text=_('Can this CC login and update the ticket?'),
         )
 
@@ -1128,8 +1170,8 @@ class TicketCC(models.Model):
         return u'%s for %s' % (self.display, self.ticket.title)
 
 class CustomFieldManager(models.Manager):
-    def get_query_set(self):
-        return super(CustomFieldManager, self).get_query_set().order_by('ordering')
+    def get_queryset(self):
+        return super(CustomFieldManager, self).get_queryset().order_by('ordering')
 
 
 class CustomField(models.Model):
@@ -1191,12 +1233,12 @@ class CustomField(models.Model):
         blank=True,
         null=True,
         )
-        
+
     empty_selection_list = models.BooleanField(
         _('Add empty first choice to List?'),
         default=False,
         help_text=_('Only for List: adds an empty first entry to the choices list, which enforces that the user makes an active choice.'),
-        )        
+        )
 
     list_values = models.TextField(
         _('List Values'),
@@ -1204,7 +1246,7 @@ class CustomField(models.Model):
         blank=True,
         null=True,
         )
-    
+
     ordering = models.IntegerField(
         _('Ordering'),
         help_text=_('Lower numbers are displayed first; higher numbers are listed later'),
@@ -1223,11 +1265,13 @@ class CustomField(models.Model):
     required = models.BooleanField(
         _('Required?'),
         help_text=_('Does the user have to enter a value for this field?'),
+        default=False,
         )
 
     staff_only = models.BooleanField(
         _('Staff Only?'),
         help_text=_('If this is ticked, then the public submission form will NOT show this field'),
+        default=False,
         )
 
     objects = CustomFieldManager()
@@ -1235,6 +1279,10 @@ class CustomField(models.Model):
     def __unicode__(self):
         return '%s' % (self.name)
 
+    class Meta:
+        verbose_name = _('Custom field')
+        verbose_name_plural = _('Custom fields')
+
 
 class TicketCustomFieldValue(models.Model):
     ticket = models.ForeignKey(
@@ -1255,11 +1303,15 @@ class TicketCustomFieldValue(models.Model):
     class Meta:
         unique_together = ('ticket', 'field'),
 
+    class Meta:
+        verbose_name = _('Ticket custom field value')
+        verbose_name_plural = _('Ticket custom field values')
+
 
 class TicketDependency(models.Model):
     """
     The ticket identified by `ticket` cannot be resolved until the ticket in `depends_on` has been resolved.
-    To help enforce this, a helper function `can_be_resolved` on each Ticket instance checks that 
+    To help enforce this, a helper function `can_be_resolved` on each Ticket instance checks that
     these have all been resolved.
     """
     ticket = models.ForeignKey(
@@ -1279,3 +1331,5 @@ class TicketDependency(models.Model):
 
     class Meta:
         unique_together = ('ticket', 'depends_on')
+        verbose_name = _('Ticket dependency')
+        verbose_name_plural = _('Ticket dependencies')
